pub struct GribFile { /* private fields */ }Expand description
A GRIB file containing one or more logical fields.
Implementations
Sourceimpl GribFile
impl GribFile
Sourcepub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
Open a GRIB file from disk using memory-mapped I/O.
Sourcepub fn open_with_options<P: AsRef<Path>>(
path: P,
options: OpenOptions,
) -> Result<Self>
pub fn open_with_options<P: AsRef<Path>>( path: P, options: OpenOptions, ) -> Result<Self>
Open a GRIB file from disk using explicit decoder options.
Sourcepub fn from_bytes(data: Vec<u8>) -> Result<Self>
pub fn from_bytes(data: Vec<u8>) -> Result<Self>
Open a GRIB file from an owned byte buffer.
Sourcepub fn from_bytes_with_options(
data: Vec<u8>,
options: OpenOptions,
) -> Result<Self>
pub fn from_bytes_with_options( data: Vec<u8>, options: OpenOptions, ) -> Result<Self>
Open a GRIB file from an owned byte buffer using explicit decoder options.
Sourcepub fn message_count(&self) -> usize
pub fn message_count(&self) -> usize
Returns the number of logical fields in the file.
Sourcepub fn messages(&self) -> MessageIter<'_> ⓘ
pub fn messages(&self) -> MessageIter<'_> ⓘ
Iterate over all fields.